Learn R Programming

ILSM (version 1.1.0.1)

PPH_Coltparkmeadow: An empirical tripartite pollinator-plant-herbivore network

Description

A pollinator-plant-herbivore tripartite network from Villa-Galaviz et. al. 2020. Journal of Animal Ecology

Usage

data(PPH_Coltparkmeadow)

Arguments

Details

An 'igraph' object. This is an empirical tripartite network provided in Villa-Galaviz et. al. 2020. This network has three guilds of species: pollinators, plants and herbivores. Pollinators and plants form the subnetwork with mutualistic interactions, and plants and herbivores form the subnetwork with antagonistic interactions. No intra-guild interactions. Plants are the shared set of species.

References

Villa-Galaviz, E., S. M. Smart, E. L. Clare, S. E. Ward, and J. Memmott. 2021. Differential effects of fertilisers on pollination and parasitoid interaction networks. Journal of animal ecology 90:404-414.

Examples

Run this code
data(PPH_Coltparkmeadow)

Run the code above in your browser using DataLab