build_toy_net: Generating an example tripartite network randomly
Description
Generate a binary tripartite network with three groups of nodes (a-, b- and c-nodes) and two subnetworks (P and Q). Subnetwork P contains links between a- and b-nodes; Subnetwork Q contains links between b- and c-nodes;b-nodes (some of which are connector nodes) are shared nodes between two subnetworks.
The probability of creating a link between any two nodes. It ranges from 0 to 1.
output_matrices
Logical. Whether to output the entire adjacency matrix of the network and subnetworks. Defaults to FALSE.
References
Pilosof, S., Porter, M., Pascual, M. et al. The multilayer nature of ecological networks. Nat Ecol Evol 1, 0101 (2017). https://doi.org/10.1038/s41559-017-0101